==> wisp_flash-0.2.0.tar: src/wisp_flash.erl <==
-module(wisp_flash).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([get_flash/2, set_flash/4]).

-spec set_flash_with_exp(
    gleam@http@response:response(wisp:body()),
    gleam@http@request:request(wisp:connection()),
    binary(),
    binary(),
    integer()
) -> gleam@http@response:response(wisp:body()).
set_flash_with_exp(Response, Request, Kind, Message, Expiration) ->
    _pipe = Response,
    _pipe@1 = wisp:set_cookie(
        _pipe,
        Request,
        <<"alert_kind"/utf8>>,
        Kind,
        plain_text,
        Expiration
    ),
    wisp:set_cookie(
        _pipe@1,
        Request,
        <<"alert_message"/utf8>>,
        Message,
        plain_text,
        Expiration
    ).

-spec get_flash_in(gleam@http@request:request(wisp:connection())) -> {gleam@option:option(binary()),
    gleam@option:option(binary())}.
get_flash_in(Request) ->
    Kind = begin
        _pipe = wisp:get_cookie(Request, <<"alert_kind"/utf8>>, plain_text),
        gleam@option:from_result(_pipe)
    end,
    Message = begin
        _pipe@1 = wisp:get_cookie(Request, <<"alert_message"/utf8>>, plain_text),
        gleam@option:from_result(_pipe@1)
    end,
    {Kind, Message}.

-spec get_flash_out(
    gleam@http@response:response(wisp:body()),
    gleam@http@request:request(wisp:connection())
) -> gleam@http@response:response(wisp:body()).
get_flash_out(Response, Request) ->
    set_flash_with_exp(Response, Request, <<""/utf8>>, <<""/utf8>>, 0).

-spec get_flash(
    gleam@http@request:request(wisp:connection()),
    fun((gleam@option:option(binary()), gleam@option:option(binary())) -> gleam@http@response:response(wisp:body()))
) -> gleam@http@response:response(wisp:body()).
get_flash(Request, Next) ->
    {Kind, Message} = get_flash_in(Request),
    Response = Next(Kind, Message),
    get_flash_out(Response, Request).

-spec set_flash(
    gleam@http@response:response(wisp:body()),
    gleam@http@request:request(wisp:connection()),
    binary(),
    binary()
) -> gleam@http@response:response(wisp:body()).
set_flash(Response, Request, Kind, Message) ->
    set_flash_with_exp(Response, Request, Kind, Message, 15).

==> wisp_flash-0.3.0.tar: src/wisp_flash.erl <==
-module(wisp_flash).
-compile([no_auto_import, nowarn_unused_vars, nowarn_unused_function, nowarn_nomatch]).

-export([get_flash/2, set_flash/4]).

-spec set_flash_with_exp(
    gleam@http@response:response(wisp:body()),
    gleam@http@request:request(wisp:connection()),
    binary(),
    binary(),
    integer()
) -> gleam@http@response:response(wisp:body()).
set_flash_with_exp(Response, Request, Kind, Message, Expiration) ->
    _pipe = Response,
    _pipe@1 = wisp:set_cookie(
        _pipe,
        Request,
        <<"alert_kind"/utf8>>,
        Kind,
        signed,
        Expiration
    ),
    wisp:set_cookie(
        _pipe@1,
        Request,
        <<"alert_message"/utf8>>,
        Message,
        signed,
        Expiration
    ).

-spec get_flash_in(gleam@http@request:request(wisp:connection())) -> {gleam@option:option(binary()),
    gleam@option:option(binary())}.
get_flash_in(Request) ->
    Kind = begin
        _pipe = wisp:get_cookie(Request, <<"alert_kind"/utf8>>, signed),
        gleam@option:from_result(_pipe)
    end,
    Message = begin
        _pipe@1 = wisp:get_cookie(Request, <<"alert_message"/utf8>>, signed),
        gleam@option:from_result(_pipe@1)
    end,
    {Kind, Message}.

-spec get_flash_out(
    gleam@http@response:response(wisp:body()),
    gleam@http@request:request(wisp:connection())
) -> gleam@http@response:response(wisp:body()).
get_flash_out(Response, Request) ->
    set_flash_with_exp(Response, Request, <<""/utf8>>, <<""/utf8>>, 0).

-spec get_flash(
    gleam@http@request:request(wisp:connection()),
    fun((gleam@option:option(binary()), gleam@option:option(binary())) -> gleam@http@response:response(wisp:body()))
) -> gleam@http@response:response(wisp:body()).
get_flash(Request, Next) ->
    {Kind, Message} = get_flash_in(Request),
    Response = Next(Kind, Message),
    get_flash_out(Response, Request).

-spec set_flash(
    gleam@http@response:response(wisp:body()),
    gleam@http@request:request(wisp:connection()),
    binary(),
    binary()
) -> gleam@http@response:response(wisp:body()).
set_flash(Response, Request, Kind, Message) ->
    set_flash_with_exp(Response, Request, Kind, Message, 15).
